@@ -1,13 +1,10 @@
-# -*- coding: utf-8 -*-
 # SPDX-License-Identifier: ISC
 # Copyright (c) 2012 Justus Winter <4winter@informatik.uni-hamburg.de>
 # Copyright (c) 2013 Patrick Gerken <do3cc@patrick-gerken.de>
 # Copyright (c) 2013 Patrick Totzke <patricktotzke@gmail.com>
 # Copyright (c) 2014 Lars Kellogg-Stedman <lars@redhat.com>
 
-from __future__ import print_function, absolute_import, unicode_literals
-
-from .BaseFilter import Filter
+from afew.filters.BaseFilter import Filter
 
 import re
 
@@ -29,6 +26,6 @@ class HeaderMatchingFilter(Filter):
                 match = self.pattern.search(value)
                 if match:
                     sub = (lambda tag:
-                        tag.format(**match.groupdict()).lower())
+                           tag.format(**match.groupdict()).lower())
                     self.remove_tags(message, *map(sub, self._tags_to_remove))
                     self.add_tags(message, *map(sub, self._tags_to_add))
